# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-26 16:48
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0027_auto_20170113_1746'),
    ]

    operations = [
        migrations.AlterField(
            model_name='apply',
            name='username',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='name'),
        ),
        migrations.AlterField(
            model_name='project',
            name='image',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='ovp_uploads.UploadedImage', verbose_name='image'),
        ),
    ]
