# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-10-25 17:26
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0005_auto_20161025_1627'),
    ]

    operations = [
        migrations.RenameField(
            model_name='project',
            old_name='googleaddress',
            new_name='address',
        ),
    ]
