# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2017-01-12 16:44
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0023_auto_20170112_1417'),
    ]

    operations = [
        migrations.AddField(
            model_name='apply',
            name='phone',
            field=models.CharField(blank=True, max_length=30, null=True, verbose_name='phone'),
        ),
        migrations.AddField(
            model_name='apply',
            name='username',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='username'),
        ),
    ]
