# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-11-15 17:44
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0010_auto_20161102_2131'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='availability',
            options={'verbose_name': 'availability', 'verbose_name_plural': 'availabilities'},
        ),
        migrations.AlterModelOptions(
            name='job',
            options={'verbose_name': 'job', 'verbose_name_plural': 'jobs'},
        ),
        migrations.AlterModelOptions(
            name='jobdate',
            options={'verbose_name': 'job date', 'verbose_name_plural': 'job dates'},
        ),
        migrations.AlterModelOptions(
            name='project',
            options={'verbose_name': 'project', 'verbose_name_plural': 'projects'},
        ),
        migrations.AlterModelOptions(
            name='role',
            options={'verbose_name': 'volunteer role', 'verbose_name_plural': 'volunteer roles'},
        ),
        migrations.RemoveField(
            model_name='project',
            name='roles',
        ),
    ]
