# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-01-30 16:31
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0030_auto_20170130_1630'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='hidden_address',
            field=models.BooleanField(default=False, verbose_name='Hidden address'),
        ),
    ]
