# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-11-15 23:02
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('ovp_projects', '0013_project_roles'),
    ]

    operations = [
        migrations.CreateModel(
            name='Apply',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(max_length=30, verbose_name='name')),
                ('date', models.DateTimeField(auto_now_add=True)),
                ('canceled', models.BooleanField(default=False, verbose_name='Canceled')),
                ('canceled_date', models.DateTimeField(blank=True, null=True, verbose_name='Canceled date')),
                ('email', models.CharField(blank=True, max_length=200, null=True, verbose_name='Email')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='ovp_projects.Project')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name_plural': 'applies',
                'verbose_name': 'apply',
            },
        ),
    ]
