# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-12-07 17:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0020_work_can_be_done_remotely'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='max_applies_from_roles',
            field=models.IntegerField(default=0),
        ),
    ]
