# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-11-02 21:22
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_projects', '0008_project_organization'),
    ]

    operations = [
        migrations.AlterField(
            model_name='project',
            name='image',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to='ovp_uploads.UploadedImage'),
        ),
    ]
